package fr.inra.pappso.xtandempipeline;

/*
 * Copyright © 2011, Benoit Valot, Olivier Langella

 This file is part of XtandemPipeline.

 XtandemPipeline is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 XtandemPipeline is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with XtandemPipeline.  If not, see <http://www.gnu.org/licenses/>.

 */

import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;

import org.apache.commons.codec.binary.Base64;
import org.apache.log4j.Logger;
import org.apache.log4j.PropertyConfigurator;

import fr.inra.pappso.xtandempipeline.ui.swt.Main_Windows;

public class XtandemPipelineMain {
	private static final Logger logger = Logger
			.getLogger(XtandemPipelineMain.class);

	/**
	 * @param args
	 * @return
	 * @return
	 */
	static public String version = "3.1.5";
	static public String versionName = "Kératine Moustachue";

	public static String about = "X!Tandem Pipeline is developped by PAPPSO team (http://pappso.inra.fr) by Benoit Valot and Olivier langella.\n\n"
			+ "This software is distributed under the terms of the GNU General Public License.\n\n"
			+ "For more information on X!Tandem search tools, see http://www.thegpm.org/tandem/";

	public static String warning = "Evalue protein has been changed\n"
			+ "Now, the evalue protein is calculated by the product of unique peptide evalues.\n\n"
			+ "If a protein is identified by two peptides with an evalue of O.O1, the protein evalue is O.OOO1.\n\n"
			+ "So, we preconise to put -4 for the protein evalue filter instead of -8.";

	public static String news = "3.1.5 : Add support of phosphorylation neutral loss and enhanced ETD detection on MS2 spectra.\n"
			+ "Correction of MassChroQ export.\n\n" 
			+ "3.1.4 : Add support for viewving ETD spectra after automatic detection.\n\n"
			+ "3.1.3 : Corrected bug of xtandem preset. Refine analysis was never start instead refine param is set to yes\n"
			+ "Adds a new annotated spectrum renderer and bug fix on ODS export\n\n"
			+ "3.1.2 : Add export results on Open Document Spreadsheet (.ods) file.\n"
			+ "Correction of bugs (Grouping, PepNovo export, ...).\n\n"
			+ "3.1.1 : FDR computation are now compatible with reverse option of X!Tandem.\n\n"
			+ "3.1.0 : Algorithm of grouping have been completly rewritten : \n"
			+ "Older project must be refiltered to be properly grouped.\n\n"
			+ "Phosphopeptide filtering have been enhanced to correspond to :\n"
			+ "- SubGroup represents the number of phosphosites\n"
			+ "- Group represents the number of phosphoproteins\n\n"
			+ "Configuration file have been modified and must be parameter again";

	public static void main(String[] args) {

		// Chargement en release mode
		if (System.getProperty("os.name").contains("Linux")) {
			PropertyConfigurator.configure(XtandemPipelineMain.class
					.getResource("/conf/log4j.linux.properties"));
			logger.info("Linux logging");
			// System.out.print("Linux logging");
		} else {
			PropertyConfigurator.configure(XtandemPipelineMain.class
					.getResource("/conf/log4j.windows.properties"));
			logger.info("Window logging");
			// System.out.print("Window logging");
		}
		if (args.length > 0) {
			try {
				logger.debug("URL specified in aguments :" + args[0]);
				URL urlOfXpipData = new URL(args[0]);

				URLConnection uc;
				try {
					uc = urlOfXpipData.openConnection();

					if (args.length > 2) {
						String userpass = args[1] + ":" + args[2];
						XtandemPipelineSession.getInstance()
								.setPROTICportController(urlOfXpipData,
										args[1], args[2]);
						String basicAuth = "Basic "
								+ new String(new Base64().encode(userpass
										.getBytes()));
						uc.setRequestProperty("Authorization", basicAuth);
					}
					InputStream in = uc.getInputStream();

					logger.info("Starting new main with ProticPort");
					new Main_Windows(in);
				} catch (IOException e) {
					logger.error("unable to open URL "
							+ urlOfXpipData.toString());
					new Main_Windows(null);
				}
			} catch (MalformedURLException e) {
				logger.error("MalformedURLException on " + args[0]);
				new Main_Windows(null);
			}
		} else {
			logger.info("Starting new main in classic mode");
			new Main_Windows(null);
		}
	}
}
